@@ -2,18 +2,20 @@
 impermium
 ~~~~~~~~~
 
-from impermium import ImpermiumAPI
+:copyright: (c) 2011 DISQUS.
+:license: Apache License 2.0, see LICENSE for more details.
 
-impermium = ImpermiumAPI(api_key=api_key)
+>>> from impermium import ImpermiumAPI
+>>> impermium = ImpermiumAPI(api_key=api_key)
 
-response = impermium.checkComment(event_id, {
-    'uid_ref': '12341234',
-    'resource_url': 'http://example.com',
-    'content': 'Hello world!',
-})
+>>> response = impermium.checkComment(event_id, {
+>>>     'uid_ref': '12341234',
+>>>     'resource_url': 'http://example.com',
+>>>     'content': 'Hello world!',
+>>> })
 
-if response['spam']['label'] == 'spam':
-    print "Uh oh, it's spam!"
+>>> if response['spam']['label'] == 'spam':
+>>>     print "Uh oh, it's spam!"
 
 """
 try:
@@ -38,7 +40,7 @@ class ImpermiumAPI(object):
     
     def __init__(self, api_key, version='2.0'):
         self.api_key = api_key
-        self.version = version
+        self.version = str(version)
     
     def request(self, http_method, type_, action, event_id=None, params={}):
         path = '/%(type)s/%(action)s/%(version)s/%(api_key)s' % dict(
@@ -84,3 +86,12 @@ class ImpermiumAPI(object):
     # Endpoints which train with content
     trainAnalyst = lambda s, *a, **k: s.request('POST', 'feedback', 'analyst', *a, **k)
     trainEnduser = lambda s, *a, **k: s.request('POST', 'feedback', 'enduser', *a, **k)
+
+    # API 3.0 endpoints
+    def trainAnalystComment(self, *args, **kwargs):
+        assert self.version == '3.0'
+        return self.request('POST', 'content/comment', 'analystfeedback', *args, **kwargs)
+
+    def trainEnduserComment(self, *args, **kwargs):
+        assert self.version == '3.0'
+        return self.request('POST', 'content/comment', 'userfeedback', *args, **kwargs)
